package org.sunflow.core.shader;

import org.sunflow.SunflowAPI;
import org.sunflow.core.ParameterList;
import org.sunflow.core.ShadingState;
import org.sunflow.core.Texture;
import org.sunflow.core.TextureCache;
import org.sunflow.image.Color;

public class TexturedShinyDiffuseShader extends ShinyDiffuseShader {
    private Texture tex;

    public TexturedShinyDiffuseShader() {
        tex = null;
    }

    public boolean update(ParameterList pl, SunflowAPI api) {
        String filename = pl.getString("texture", null);
        if (filename != null)
            tex = TextureCache.getTexture(api.resolveTextureFilename(filename), false);
        return tex != null && super.update(pl, api);
    }

    public Color getDiffuse(ShadingState state) {
    	
    	Color diffuse = super.getDiffuse(state);
    	
    	
    	//System.out.println(state.getUV() + " -- > "+state.getU()+","+state.getV());
    	if((state.getUV().x < 0) || (state.getUV().y < 0))
    	{
    		return diffuse;
    	}
    	if((state.getUV().x >= 1) || (state.getUV().y >= 1))
    	{
    		return diffuse;
    	}
    	
    	
    	
    	int alpha = tex.getAlpha(state.getUV().x, state.getUV().y);
    	
    	if(alpha == 0)  return diffuse; 
    	
    	Color texture = tex.getPixel(state.getUV().x, state.getUV().y);
    	
    	if (alpha == 255) return texture;
    	
    	float a = ((float)alpha) / 255f;
    	return Color.add(Color.mul(a, texture), Color.mul(1f-a, diffuse));
    	
    	
        // blend
    }
}